/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: ProtocolConfig.java 2438 2010-02-24 16:20:30Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.config;

/**
 * Define the configuration of a protocol.
 *
 * @author Loris Bouzonnet
 */
public final class ProtocolConfig {

    /**
     * Protocol name.
     */
    private String name;

    /**
     * True disable CMI for this protocol.
     */
    private boolean noCmi = false;

    /**
     * The provider URLs of some cluster view providers.
     */
    private ProviderUrls providerUrls;

    /**
     * The provider URL of a local registry.
     */
    private String localRegistryUrl;

    /**
     * The initial context factory name.
     */
    private String initialContextFactoryName;

    /**
     * @return the protocol name
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the protocol name.
     *
     * @param protocol
     *            a name of protocol
     */
    public void setName(final String protocol) {
        this.name = protocol;
    }

    /**
     * @return true if CMI is disabled for this protocol
     */
    public boolean isNoCmi() {
        return noCmi;
    }

    /**
     * Set if CMI is disabled for this protocol.
     *
     * @param noCmi
     *            true if CMI is disabled for this protocol
     */
    public void setNoCmi(final boolean noCmi) {
        this.noCmi = noCmi;
    }

    /**
     * @return the provider URLs of some cluster view providers
     */
    public ProviderUrls getProviderUrls() {
        return providerUrls;
    }

    /**
     * Set the provider URLs of some cluster view providers.
     *
     * @param providerUrls
     *            the provider URLs of some cluster view providers
     */
    public void setProviderUrls(final ProviderUrls providerUrls) {
        this.providerUrls = providerUrls;
    }

    /**
     * @return the provider URL of a local registry
     */
    public String getLocalRegistryUrl() {
        return localRegistryUrl;
    }

    /**
     * Set the provider URL of a local registry.
     *
     * @param localRegistryUrl
     *            the provider URL of a local registry
     */
    public void setLocalRegistryUrl(final String localRegistryUrl) {
        this.localRegistryUrl = localRegistryUrl;
    }

    /**
     * @return the initial context factory name
     */
    public String getInitialContextFactoryName() {
        return initialContextFactoryName;
    }

    /**
     * Set the initial context factory name.
     *
     * @param initialContextFactoryName
     *            the initial context factory name
     */
    public void setInitialContextFactoryName(
            final String initialContextFactoryName) {
        this.initialContextFactoryName = initialContextFactoryName;
    }

    /**
     * @return String representation of the protocol configuration.
     */
    @Override
    public String toString() {
        String ret = "name: " + name + "no CMI:" + noCmi;
        if (initialContextFactoryName != null) {
            ret += "initial context factory : " + initialContextFactoryName;
        }
        if (localRegistryUrl != null) {
            ret +=  " local registry url: " + localRegistryUrl;
        }
        if (providerUrls != null) {
            ret += " Provider urls: " + providerUrls.toString();
        }
        return ret;
    }
}
