/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: AbstractEvent.java 2438 2010-02-24 16:20:30Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.cmi.event;
import org.ow2.util.event.api.IEventListener;
/**
 * Abstract parent class for all CMI events.
 * @author Loris Bouzonnet
 */
public abstract class AbstractEvent implements CMIEvent {

    /**
     * The next event number.
     */
    private static long nextNumber = 1;

    /**
     * The event number.
     */
    private long number;

    /**
     * The event time.
     */
    private long time;

    /**
     * The event source.
     */
    private String source;

    /**
     * The default constructor.
     * @param source The event source.
     */
    public AbstractEvent(final String source) {
        this.number = AbstractEvent.nextNumber++;
        this.time = System.currentTimeMillis();
        this.source = source;
    }

    /**
     * Get the event number.
     * @return The event number.
     */
    public long getNumber() {
        return this.number;
    }

    /**
     * Get the event time (ms).
     * @return The event time (ms).
     */
    public long getTime() {
        return this.time;
    }

    /**
     * Get the event provider id.
     * @return The event provider id.
     */
    public String getEventProviderId() {
        return this.source;
    }

    /**
     * Check whether the event listener has permission to receive this event.
     * @param eventListener The event listener to check.
     * @return True if the listener has the permission, false otherwise.
     */
    public boolean checkPermission(final IEventListener eventListener){
        return true;
    }

}
